<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN"
   "http://www.w3.org/TR/html4/strict.dtd">
<html>
    <head>
        <title>Creating Cookie</title>
    </head>
    <body>
        <script src="//ajax.googleapis.com/ajax/libs/jquery/1.7.2/jquery.min.js" type="text/javascript"></script>
        <script type="text/javascript">
            $(document).ready(function() {

                var name = 'safari.cookie.fix'
                var value = 'fixed'
                var minutes = 10

                var date = new Date();
                date.setTime(date.getTime()+(minutes*60*1000));
                var expires = "; expires="+date.toGMTString();

                document.cookie = name+"="+value+expires+"; path=/";

                window.close();
            });
        </script>
    </body>
</html>
